@@ -59,6 +59,7 @@ pub struct SqlBuilder {
 /// SQL query statement
 enum Statement {
     SelectFrom,
+    SelectValues,
     UpdateTable,
     InsertInto,
     DeleteFrom,
@@ -119,6 +120,31 @@ impl SqlBuilder {
         }
     }
 
+    /// Create SELECT query without a table.
+    ///
+    /// ```
+    /// extern crate sql_builder;
+    ///
+    /// # use std::error::Error;
+    /// use sql_builder::{SqlBuilder, quote};
+    ///
+    /// # fn main() -> Result<(), Box<dyn Error>> {
+    /// let sql = SqlBuilder::select_values(&["10", &quote("100")])
+    ///     .sql()?;
+    ///
+    /// assert_eq!("SELECT 10, '100';", &sql);
+    /// # Ok(())
+    /// # }
+    /// ```
+    pub fn select_values(values: &[&str]) -> Self {
+        let mut sel = Self {
+            statement: Statement::SelectValues,
+            ..Self::default()
+        };
+        sel.fields(values);
+        sel
+    }
+
     /// Create INSERT query.
     ///
     /// ```
@@ -813,6 +839,7 @@ impl SqlBuilder {
     pub fn sql(&self) -> Result<String, Box<dyn Error>> {
         match self.statement {
             Statement::SelectFrom => self.sql_select(),
+            Statement::SelectValues => self.sql_select_values(),
             Statement::UpdateTable => self.sql_update(),
             Statement::InsertInto => self.sql_insert(),
             Statement::DeleteFrom => self.sql_delete(),
@@ -821,11 +848,30 @@ impl SqlBuilder {
 
     /// Build complete SQL command for SELECT statement
     fn sql_select(&self) -> Result<String, Box<dyn Error>> {
+        // Checks
+        if self.table.is_empty() {
+            return Err("No table name".into());
+        }
+
+        // Build query
         let mut text = self.query()?;
         text.push(';');
         Ok(text)
     }
 
+    /// Build complete SQL command for SELECT statement without a table
+    fn sql_select_values(&self) -> Result<String, Box<dyn Error>> {
+        // Checks
+        if self.fields.is_empty() {
+            return Err("No values".into());
+        }
+
+        // Build query
+        let mut text = self.query_values()?;
+        text.push(';');
+        Ok(text)
+    }
+
     /// Build subquery SQL command.
     ///
     /// ```
@@ -917,11 +963,6 @@ impl SqlBuilder {
     /// # }
     /// ```
     pub fn query(&self) -> Result<String, Box<dyn Error>> {
-        // Checks
-        if self.table.is_empty() {
-            return Err("No table name".into());
-        }
-
         // Distinct results
         let distinct = if self.distinct { " DISTINCT" } else { "" };
 
@@ -988,6 +1029,31 @@ impl SqlBuilder {
         Ok(sql)
     }
 
+    /// SQL command generator for query or subquery without a table.
+    ///
+    /// ```
+    /// extern crate sql_builder;
+    ///
+    /// # use std::error::Error;
+    /// use sql_builder::{SqlBuilder, quote};
+    ///
+    /// # fn main() -> Result<(), Box<dyn Error>> {
+    /// let values = SqlBuilder::select_values(&["10", &quote("100")])
+    ///     .query_values()?;
+    ///
+    /// assert_eq!("SELECT 10, '100'", &values);
+    /// # Ok(())
+    /// # }
+    /// ```
+    pub fn query_values(&self) -> Result<String, Box<dyn Error>> {
+        // Make values
+        let fields = self.fields.join(", ");
+
+        // Make SQL
+        let sql = format!("SELECT {fields}", fields = fields,);
+        Ok(sql)
+    }
+
     /// Build SQL command for INSERT statement
     fn sql_insert(&self) -> Result<String, Box<dyn Error>> {
         // Checks
@@ -1144,6 +1210,15 @@ mod tests {
         Ok(())
     }
 
+    #[test]
+    fn test_select_only_values() -> Result<(), Box<dyn Error>> {
+        let values = SqlBuilder::select_values(&["10", &quote("100")]).sql()?;
+
+        assert_eq!("SELECT 10, '100';", &values);
+
+        Ok(())
+    }
+
     #[test]
     fn test_select_all_books() -> Result<(), Box<dyn Error>> {
         let sql = SqlBuilder::select_from("books").sql()?;
